import { ConfigProvider } from "../config";

const cloudstudioUrlInput = document.getElementById(
  "cloudstudio-url-input"
)! as HTMLInputElement;
const csRewriteKeybind = document.getElementById(
  "cloudstudio-replace-keybind"
)! as HTMLInputElement;
const csPopupInput = document.getElementById(
  "cloudstudio-open-as-popup"
)! as HTMLInputElement;
const messageElement = document.getElementById("message")! as HTMLDivElement;

const init = async () => {
  const configProvider = await ConfigProvider.create();

  // Initialize UI
  const initialConfig = configProvider.getConfig();
  cloudstudioUrlInput.value = initialConfig.cloudStudioUrl;
  csPopupInput.checked = initialConfig.openAsPopup;
  csRewriteKeybind.checked = initialConfig.rewritePeriodKeybind;

  let timeout: number | undefined = undefined;

  // Save config before close
  const save = () => {
    // Update config (propagated internally)
    configProvider.setConfig({
      cloudStudioUrl: cloudstudioUrlInput.value || undefined,
      openAsPopup: csPopupInput.checked,
      rewritePeriodKeybind: csRewriteKeybind.checked,
    });
    if (timeout) {
      window.clearTimeout(timeout);
      timeout = undefined;
    }
    messageElement.innerText = "Saved.";
    timeout = window.setTimeout(() => {
      messageElement.innerText = "";
      timeout = undefined;
    }, 3000);
  };
  cloudstudioUrlInput.addEventListener("keyup", (event: KeyboardEvent) => {
    if (event.isComposing || event.keyCode === 229) {
      return;
    }
    save();
  });
  [csPopupInput, csRewriteKeybind].forEach((el) =>
    el.addEventListener("change", save)
  );
};

init().catch((err) => console.error(err));
